# ![Shaka Streamer](https://raw.githubusercontent.com/google/shaka-streamer/master/docs/source/shaka-streamer-logo.png)

Shaka Streamer offers a simple config-file based approach to preparing streaming
media. It greatly simplifies the process of using FFmpeg and Shaka Packager for
both VOD and live content.

Live documentation can be found at https://google.github.io/shaka-streamer/
and is generated from the `docs/source/` folder, as well as the source code
itself.

Release versions of Shaka Streamer can be installed or upgraded through `pip`
with:

```sh
# Use sudo on Linux to install globally
pip install --upgrade shaka-streamer
```
